# OpenBB Fixed Income Extension

This extension provides fixed income data for the OpenBB Platform.

Features of the Fixed Income extension include information on government bonds and central bank rates.

## Installation

To install the extension, run the following command in this folder:

```bash
pip install openbb-fixedincome
```

For development please check [Contribution Guidelines](https://github.com/OpenBB-finance/OpenBBTerminal/blob/develop/openbb_platform/CONTRIBUTING.md).

Documentation available [here](https://docs.openbb.co/platform).
